@@ -14,7 +14,9 @@
 #' @param maxit Maximum number of iterations for optimization. Defaults to 10000.
 #' @param abstol Absolute convergence tolerance for optimization. Defaults to 1e-08.
 #' @return A list with class \code{c("pairwise", "melt")}.
-#'
+#' @references Kim, E., MacEachern, S., and Peruggia, M., (2021),
+#' "Empirical Likelihood for the Analysis of Experimental Designs,"
+#' \href{https://arxiv.org/abs/2112.09206}{arxiv:2112.09206}.
 #' @examples
 #' ## all pairwise comparisons
 #' el_pairwise(clo ~ trt | blk, clothianidin, B = 10000)
@@ -95,7 +97,7 @@ el_pairwise <- function(formula, data, control = NULL, k = 1, alpha = 0.05,
   # general block design
   gbd <-
     list("model_matrix" = x, "incidence_matrix" = c, "trt" = levels(mf[[2L]]))
-  class(gbd) <- c("gbd", "elmulttest")
+  class(gbd) <- c("gbd", "melt")
 
   ## check whether all pairwise comparisons or comparisons to control
   match.arg(control, gbd$trt)
